==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridValidationStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebValidationErrorsDescriptionMetadata } from "./WebValidationErrorsDescriptionMetadata";
import { WebGridValidationStateDescription } from "./WebGridValidationStateDescription";
/**
 * @hidden
 */
var WebGridValidationStateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridValidationStateDescriptionMetadata, _super);
    function WebGridValidationStateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridValidationStateDescriptionMetadata.b = function (a) {
        if (WebGridValidationStateDescriptionMetadata.a == null) {
            WebGridValidationStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridValidationStateDescriptionMetadata.c(WebGridValidationStateDescriptionMetadata.a);
        }
        if (a.j(WebGridValidationStateDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridValidationStateDescriptionMetadata.a);
        WebValidationErrorsDescriptionMetadata.d(a);
    };
    WebGridValidationStateDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridValidationState");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Status", "ExportedType:string:ValidationStatus");
        a.item("Status@names", "VALID;INVALID");
        a.item("Errors", "ExportedType:WebValidationErrors");
    };
    WebGridValidationStateDescriptionMetadata.d = function (a) {
        WebGridValidationStateDescriptionMetadata.b(a);
        a.aa("WebGridValidationState", function () { return new WebGridValidationStateDescription(); });
        a.z("WebGridValidationState", WebGridValidationStateDescriptionMetadata.a);
    };
    WebGridValidationStateDescriptionMetadata.$t = markType(WebGridValidationStateDescriptionMetadata, 'WebGridValidationStateDescriptionMetadata');
    WebGridValidationStateDescriptionMetadata.a = null;
    return WebGridValidationStateDescriptionMetadata;
}(Base));
export { WebGridValidationStateDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridValidationStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebValidationErrorsDescriptionMetadata } from "./WebValidationErrorsDescriptionMetadata";
import { WebGridValidationStateDescription } from "./WebGridValidationStateDescription";
/**
 * @hidden
 */
var WebGridValidationStateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridValidationStateDescriptionMetadata, _super);
    function WebGridValidationStateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridValidationStateDescriptionMetadata.b = function (a) {
        if (WebGridValidationStateDescriptionMetadata.a == null) {
            WebGridValidationStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridValidationStateDescriptionMetadata.c(WebGridValidationStateDescriptionMetadata.a);
        }
        if (a.k(WebGridValidationStateDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridValidationStateDescriptionMetadata.a);
        WebValidationErrorsDescriptionMetadata.d(a);
    };
    WebGridValidationStateDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridValidationState");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Status", "ExportedType:string:ValidationStatus");
        a.item("Status@stringUnion", "WebComponents;React");
        a.item("Status@names", "VALID;INVALID");
        a.item("Errors", "ExportedType:WebValidationErrors");
    };
    WebGridValidationStateDescriptionMetadata.d = function (a) {
        WebGridValidationStateDescriptionMetadata.b(a);
        a.ac("WebGridValidationState", function () { return new WebGridValidationStateDescription(); });
        a.ab("WebGridValidationState", WebGridValidationStateDescriptionMetadata.a);
    };
    WebGridValidationStateDescriptionMetadata.$t = markType(WebGridValidationStateDescriptionMetadata, 'WebGridValidationStateDescriptionMetadata');
    WebGridValidationStateDescriptionMetadata.a = null;
    return WebGridValidationStateDescriptionMetadata;
}(Base));
export { WebGridValidationStateDescriptionMetadata };
